@@ -158,7 +158,7 @@ def test_requirements_finder(tmpdir) -> None:
         assert finder._normalize_name("deal") == "deal"
         assert finder._normalize_name("Django") == "django"  # lowercase
         assert finder._normalize_name("django_haystack") == "haystack"  # mapping
-        assert finder._normalize_name("Flask-RESTful") == "flask_restful"  # conver `-`to `_`
+        assert finder._normalize_name("Flask-RESTful") == "flask_restful"  # convert `-`to `_`
 
     req_file.remove()
 
@@ -178,7 +178,7 @@ def test_pipfile_finder(tmpdir) -> None:
     assert finder._normalize_name("deal") == "deal"
     assert finder._normalize_name("Django") == "django"  # lowercase
     assert finder._normalize_name("django_haystack") == "haystack"  # mapping
-    assert finder._normalize_name("Flask-RESTful") == "flask_restful"  # conver `-`to `_`
+    assert finder._normalize_name("Flask-RESTful") == "flask_restful"  # convert `-`to `_`
 
     pipfile.remove()
 
