@@ -7,7 +7,7 @@ from io import StringIO
 import pytest
 
 import isort
-from isort import Config, api, exceptions
+from isort import Config, exceptions
 
 
 def test_semicolon_ignored_for_dynamic_lines_after_import_issue_1178():
@@ -213,6 +213,19 @@ import os
 """
     )
 
+    # issue 1838: don't append in middle of class
+    assert isort.check_code(
+        '''class C:
+    """a
+
+    """
+    # comment
+''',
+        append_only=True,
+        add_imports=["from __future__ import annotations"],
+        show_diff=True,
+    )
+
 
 def test_isort_supports_shared_profiles_issue_970():
     """Test to ensure isort provides a way to use shared profiles.
@@ -224,15 +237,6 @@ def test_isort_supports_shared_profiles_issue_970():
         assert isort.code("import a", profile="madeupfake") == "import a\n"  # non-existent profile
 
 
-def test_isort_supports_formatting_plugins_issue_1353():
-    """Test to ensure isort provides a way to create and share formatting plugins.
-    See: https://github.com/pycqa/isort/issues/1353.
-    """
-    assert isort.code("import a", formatter="example") == "import a\n"  # formatting plugin
-    with pytest.raises(exceptions.FormattingPluginDoesNotExist):
-        assert isort.code("import a", formatter="madeupfake") == "import a\n"  # non-existent plugin
-
-
 def test_treating_comments_as_code_issue_1357():
     """Test to ensure isort provides a way to treat comments as code.
     See: https://github.com/pycqa/isort/issues/1357
@@ -353,175 +357,6 @@ import c
     )
 
 
-def test_isort_literals_issue_1358():
-    assert (
-        isort.code(
-            """
-import x
-import a
-
-
-# isort: list
-__all__ = ["b", "a", "b"]
-
-# isort: unique-list
-__all__ = ["b", "a", "b"]
-
-# isort: tuple
-__all__ = ("b", "a", "b")
-
-# isort: unique-tuple
-__all__ = ("b", "a", "b")
-
-# isort: set
-__all__ = {"b", "a", "b"}
-
-
-def method():
-    # isort: list
-    x = ["b", "a"]
-
-
-# isort: dict
-y = {"z": "z", "b": "b", "b": "c"}"""
-        )
-        == """
-import a
-import x
-
-# isort: list
-__all__ = ['a', 'b', 'b']
-
-# isort: unique-list
-__all__ = ['a', 'b']
-
-# isort: tuple
-__all__ = ('a', 'b', 'b')
-
-# isort: unique-tuple
-__all__ = ('a', 'b')
-
-# isort: set
-__all__ = {'a', 'b'}
-
-
-def method():
-    # isort: list
-    x = ['a', 'b']
-
-
-# isort: dict
-y = {'b': 'c', 'z': 'z'}"""
-    )
-    assert (
-        isort.code(
-            """
-import x
-import a
-
-
-# isort: list
-__all__ = ["b", "a", "b"]
-
-# isort: unique-list
-__all__ = ["b", "a", "b"]
-
-# isort: tuple
-__all__ = ("b", "a", "b")
-
-# isort: unique-tuple
-__all__ = ("b", "a", "b")
-
-# isort: set
-__all__ = {"b", "a", "b"}
-
-
-def method():
-    # isort: list
-    x = ["b", "a"]
-
-
-# isort: assignments
-d = 1
-b = 2
-a = 3
-
-# isort: dict
-y = {"z": "z", "b": "b", "b": "c"}""",
-            formatter="example",
-        )
-        == """
-import a
-import x
-
-# isort: list
-__all__ = ["a", "b", "b"]
-
-# isort: unique-list
-__all__ = ["a", "b"]
-
-# isort: tuple
-__all__ = ("a", "b", "b")
-
-# isort: unique-tuple
-__all__ = ("a", "b")
-
-# isort: set
-__all__ = {"a", "b"}
-
-
-def method():
-    # isort: list
-    x = ["a", "b"]
-
-
-# isort: assignments
-a = 3
-b = 2
-d = 1
-
-# isort: dict
-y = {"b": "c", "z": "z"}"""
-    )
-    assert api.sort_stream(
-        input_stream=StringIO(
-            """
-import a
-import x
-
-# isort: list
-__all__ = ["b", "a", "b"]
-
-# isort: unique-list
-__all__ = ["b", "a", "b"]
-
-# isort: tuple
-__all__ = ("b", "a", "b")
-
-# isort: unique-tuple
-__all__ = ("b", "a", "b")
-
-# isort: set
-__all__ = {"b", "a", "b"}
-
-
-def method():
-    # isort: list
-    x = ["b", "a"]
-
-
-# isort: assignments
-d = 1
-b = 2
-a = 3
-
-# isort: dict
-y = {"z": "z", "b": "b", "b": "c"}""",
-        ),
-        output_stream=StringIO(),
-    )
-
-
 def test_isort_allows_setting_import_types_issue_1181():
     """Test to ensure isort provides a way to set the type of imports.
     See: https://github.com/pycqa/isort/issues/1181
